import { initTRPC } from "@trpc/server"
import { prismaClient } from "../prisma"

export interface Context {
	playerId: string
}

export async function createContext(authorizationHeader: string | undefined): Promise<Context> {
	const token = authorizationHeader?.slice(7) ?? null  // "Bearer " → 7 characters

	if (token !== null && token.length > 0) {
		const player = await prismaClient.player.findUnique({ where: { token }, select: { id: true } })

		if (player !== null) return {
			playerId: player.id
		}
	}

	throw new Error("Invalid token")
}

export const t = initTRPC.context<Context>().create()
