import { t } from "./base"
import { prismaClient } from "../prisma"
import z from "zod"
import { observable } from "@trpc/server/observable"
import type { GameAction } from "../../shared/game/gameActions"
import { getGameById } from "../game"

export const appRouter = t.router({
	start: t.procedure
		.mutation(async ({ ctx }) => {

		}),

	join: t.procedure
		.input(z.object({
			gameId: z.string().nonempty()
		}))
		.subscription(({ input, ctx }) => {
			const game = getGameById(input.gameId)
			
			return observable(emit => {
				const handlePublicAction = (action: GameAction) => emit.next(action)
				
				const handlePrivateAction = (playerId: string, action: GameAction) => {
					if (playerId === ctx.playerId) emit.next(action)
				}

				game.on("public_action", handlePublicAction)
				game.on("private_action", handlePrivateAction)
				
				return () => {
					game.off("public_action", handlePublicAction)
					game.off("private_action", handlePrivateAction)
				}
			})
		})
})

export type AppRouter = typeof appRouter